package Refrigerator "Package containing models of household refrigerator in various scenarios"
  package Components "Package containing components for household refrigerator models"
    model ConvectionCooledFood "Food cooled by air"
      Modelica.Blocks.Sources.Constant heatTransfer(k = 12 * surfaceArea) annotation(Placement(visible = true, transformation(origin = {30.0, 30.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 180)));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor food(C = heatCapacity, T.start = initialTemperature) annotation(Placement(visible = true, transformation(origin = {30.0, -30.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b air annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Real surfaceArea = 1 "Food surface area for convection cooling";
      parameter Modelica.SIunits.HeatCapacity heatCapacity = 10000 "Food heat capacity";
      parameter Modelica.SIunits.Temp_K initialTemperature = 273.15 "Initial temperature of food";
      Modelica.Thermal.HeatTransfer.Celsius.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {60.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Boolean frozenIcon = false;
    equation
      connect(convection.solid, temperatureSensor.port) annotation(Line(visible = true, origin = {30, 0}, points = {{-20, 0}, {20, 0}}, color = {191, 0, 0}));
      connect(heatTransfer.y, convection.Gc) annotation(Line(visible = true, origin = {6.333, 23.333}, points = {{12.667, 6.667}, {-6.333, 6.667}, {-6.333, -13.333}}, color = {1, 37, 163}));
      connect(convection.solid, food.port) annotation(Line(visible = true, origin = {23.333, -6.667}, points = {{-13.333, 6.667}, {6.667, 6.667}, {6.667, -13.333}}, color = {191, 0, 0}));
      connect(convection.fluid, air) annotation(Line(visible = true, origin = {-80, 0}, points = {{70, 0}, {-70, 0}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART ConvectionCooledFood -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Convection-Cooled Food</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models food cooled by air in the refrigerator or freezer compartment.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.Components.ConvectionCooledFood#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND ConvectionCooledFood --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Bitmap(visible = not frozenIcon, fileName = "modelica://Refrigerator/DocumentationFiles/Food.png", imageSource = "", extent = {{-100, -100}, {100, 100}}), Text(visible = true, origin = {-3, -12}, textColor = {0, 0, 255}, extent = {{-117, -128}, {124, -88}}, textString = "%name", fontName = "Arial"), Bitmap(visible = frozenIcon, fileName = "modelica://Refrigerator/DocumentationFiles/FrozenFood.png", imageSource = "", extent = {{-100, -100}, {100, 100}})}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end ConvectionCooledFood;

    model OuterCase "Household refrigerator case and insulation"
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor freezerInsulation(G = 0.875 * 4 / 8) annotation(Placement(visible = true, transformation(origin = {1.5367, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor fridgeInsulation(G = 2.19 * 4 / 6) annotation(Placement(visible = true, transformation(origin = {1.5367, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection3 annotation(Placement(visible = true, transformation(origin = {40.0, -40.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 180)));
      Modelica.Blocks.Sources.Constant const3(k = 12) annotation(Placement(visible = true, transformation(origin = {0.0, 80.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 270)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection4 annotation(Placement(visible = true, transformation(origin = {40.0, 40.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = -180)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection6 annotation(Placement(visible = true, transformation(origin = {-40.0, 40.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 180)));
      Modelica.Blocks.Sources.Constant const6(k = 30) annotation(Placement(visible = true, transformation(origin = {-0.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection7 annotation(Placement(visible = true, transformation(origin = {-40.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b freezerAir annotation(Placement(visible = true, transformation(origin = {150.0, 100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, 100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b fridgeAir annotation(Placement(visible = true, transformation(origin = {150.0, -100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, -100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b ambientAir annotation(Placement(visible = true, transformation(origin = {-150.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-102.1394, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(convection3.fluid, fridgeAir) annotation(Line(visible = true, origin = {115, -70}, points = {{-65, 30}, {15, 30}, {15, -30}, {35, -30}}, color = {191, 0, 0}));
      connect(convection4.fluid, freezerAir) annotation(Line(visible = true, origin = {115, 70}, points = {{-65, -30}, {15, -30}, {15, 30}, {35, 30}}, color = {191, 0, 0}));
      connect(convection6.fluid, ambientAir) annotation(Line(visible = true, origin = {-90, 20}, points = {{40, 20}, {10, 20}, {10, -20}, {-60, -20}}, color = {191, 0, 0}));
      connect(convection7.fluid, ambientAir) annotation(Line(visible = true, origin = {-90.419, -20}, points = {{40.419, -20}, {10.419, -20}, {10.419, 20}, {-59.581, 20}}, color = {191, 0, 0}));
      connect(convection4.Gc, const3.y) annotation(Line(visible = true, origin = {20, 62.75}, points = {{20, -12.75}, {20, 3.25}, {-20, 3.25}, {-20, 6.25}}, color = {0, 36, 164}));
      connect(convection6.Gc, const3.y) annotation(Line(visible = true, origin = {-20, 62.75}, points = {{-20, -12.75}, {-20, 3.25}, {20, 3.25}, {20, 6.25}}, color = {0, 36, 164}));
      connect(convection3.Gc, const6.y) annotation(Line(visible = true, origin = {20, -62.75}, points = {{20, 12.75}, {20, -3.25}, {-20, -3.25}, {-20, -6.25}}, color = {0, 36, 164}));
      connect(convection7.Gc, const6.y) annotation(Line(visible = true, origin = {-20, -62.75}, points = {{-20, 12.75}, {-20, -3.25}, {20, -3.25}, {20, -6.25}}, color = {0, 36, 164}));
      connect(fridgeInsulation.port_b, convection3.solid) annotation(Line(visible = true, origin = {20.768, -40}, points = {{-9.232, 0}, {9.232, 0}}, color = {191, 0, 0}));
      connect(fridgeInsulation.port_a, convection7.solid) annotation(Line(visible = true, origin = {-19.232, -40}, points = {{10.768, 0}, {-10.768, 0}}, color = {191, 0, 0}));
      connect(convection4.solid, freezerInsulation.port_b) annotation(Line(visible = true, origin = {20.768, 40}, points = {{9.232, 0}, {-9.232, 0}}, color = {191, 0, 0}));
      connect(freezerInsulation.port_a, convection6.solid) annotation(Line(visible = true, origin = {-19.232, 40}, points = {{10.768, 0}, {-10.768, 0}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART OuterCase -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Outer Case</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the insulated case of the refrigerator and freezer compartments.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.Components.OuterCase#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND OuterCase --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {255, 255, 255}, extent = {{-30.0, -60.0}, {30.0, 60.0}}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-6.0, 50.0}, points = {{36.0, -20.0}, {86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, 50.0}, points = {{56.0, -30.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, 50.0}, points = {{56.0, -10.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-6.0, -10.0}, points = {{36.0, -20.0}, {86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, -10.0}, points = {{56.0, -30.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, -10.0}, points = {{56.0, -10.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {6.0, 50.0}, points = {{-36.0, -20.0}, {-86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, 50.0}, points = {{-56.0, -30.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, 50.0}, points = {{-56.0, -10.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {6.0, -10.0}, points = {{-36.0, -20.0}, {-86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, -10.0}, points = {{-56.0, -30.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, -10.0}, points = {{-56.0, -10.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Text(visible = true, origin = {-3.5, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial"), Line(visible = true, origin = {0.0, 10.0}, points = {{-30.0, 0.0}, {30.0, 0.0}}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255})}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {0.0, 95.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "1 m^2 surface", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 25.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "8 cm polyfoam", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "6 cm polyfoam", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -95.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2.5 m^2 surface", fontSize = 12, fontName = "Arial")}));
    end OuterCase;

    model AirCirculation "Thermostat-controlled air circulation between compartments"
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow airCirculation(useVolumeFlowInput = true, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.01, T0 = 273.15) annotation(Placement(visible = true, transformation(origin = {110.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Sources.AbsolutePressure pressure(p = 101325, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {80.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 90)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowPort_a1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FromKelvin celsius annotation(Placement(visible = true, transformation(origin = {-60.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Hysteresis thermostat(uHigh = 5, uLow = 2) annotation(Placement(visible = true, transformation(origin = {-20.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {70.0, 40.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 720)));
      Modelica.Blocks.Sources.Constant fanOff(k = 0) annotation(Placement(visible = true, transformation(origin = {20.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant fanOn(k = 0.003) annotation(Placement(visible = true, transformation(origin = {20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {-100.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a fridgeAir annotation(Placement(visible = true, transformation(origin = {0.0, 105.8333}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {0.0, 100.7937}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(celsius.Celsius, thermostat.u) annotation(Line(visible = true, origin = {-40.5, 40}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
      connect(temperatureSensor.T, celsius.Kelvin) annotation(Line(visible = true, origin = {-81, 40}, points = {{-9, 0}, {9, 0}}, color = {1, 37, 163}));
      connect(switch.y, airCirculation.volumeFlow) annotation(Line(visible = true, origin = {100.333, 30}, points = {{-19.333, 10}, {9.667, 10}, {9.667, -20}}, color = {1, 37, 163}));
      connect(temperatureSensor.port, fridgeAir) annotation(Line(visible = true, origin = {-74, 73.167}, points = {{-36, -33.167}, {-56, -33.167}, {-56, 16.833}, {74, 16.833}, {74, 32.667}}, color = {191, 0, 0}));
      connect(thermostat.y, switch.u2) annotation(Line(visible = true, origin = {24.5, 40}, points = {{-33.5, 0}, {33.5, 0}}, color = {190, 52, 178}));
      connect(fanOff.y, switch.u3) annotation(Line(visible = true, origin = {42.25, 54}, points = {{-11.25, 6}, {-2.25, 6}, {-2.25, -6}, {15.75, -6}}, color = {1, 37, 163}));
      connect(fanOn.y, switch.u1) annotation(Line(visible = true, origin = {42.25, 26}, points = {{-11.25, -6}, {-2.25, -6}, {-2.25, 6}, {15.75, 6}}, color = {1, 37, 163}));
      connect(airCirculation.flowPort_b, flowPort_b1) annotation(Line(visible = true, origin = {135, 0}, points = {{-15, 0}, {15, 0}}, color = {190, 20, 31}));
      connect(airCirculation.flowPort_a, flowPort_a1) annotation(Line(visible = true, origin = {-25, 0}, points = {{125, 0}, {-125, 0}}, color = {190, 20, 31}));
      connect(airCirculation.flowPort_a, pressure.flowPort) annotation(Line(visible = true, origin = {86.667, -6.667}, points = {{13.333, 6.667}, {-6.667, 6.667}, {-6.667, -13.333}}, color = {190, 20, 31}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART AirCirculation -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Air Circulation</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the thermostat-controlled air circulation between the refrigerator and freezer compartments.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.Components.AirCirculation#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND AirCirculation --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, lineColor = {255, 0, 0}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-90.0, -90.0}, {90.0, 90.0}}), Polygon(visible = true, lineColor = {255, 0, 0}, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-60.0, 68.0}, {90.0, 10.0}, {90.0, -10.0}, {-60.0, -68.0}, {-60.0, 68.0}}), Text(visible = true, extent = {{-40.0, -20.0}, {0.0, 20.0}}, textString = "V", fontName = "Arial"), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end AirCirculation;

    model CompartmentDoor "Refrigerator or freezer compartment door"
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow circulationInDoor(useVolumeFlowInput = true, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.01, T0 = 293.15) annotation(Placement(visible = true, transformation(origin = {40.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowPort_a1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {-30.0, 60.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 720)));
      Modelica.Blocks.Sources.Constant fanOff(k = 0) annotation(Placement(visible = true, transformation(origin = {-80.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant fanOn(k = airFlow) annotation(Placement(visible = true, transformation(origin = {-80.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.BooleanTable openCloseTable(table = schedule) annotation(Placement(visible = true, transformation(origin = {-120.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Time schedule[:] = {1000, 1010} "Schedule of door open and close times";
      parameter Modelica.SIunits.VolumeFlowRate airFlow = 0.001 "Air flow rate while door is open";
      Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), constantAmbientPressure = 101325, constantAmbientTemperature = 293.15) annotation(Placement(visible = true, transformation(origin = {-10.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow circulationOutDoor(m = 0.01, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), useVolumeFlowInput = true, T0 = 293.15) annotation(Placement(visible = true, transformation(origin = {-30.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure = 101325, constantAmbientTemperature = 293.15, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {20.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
    equation
      connect(ambient1.flowPort, circulationInDoor.flowPort_a) annotation(Line(visible = true, origin = {23.333, -10}, points = {{-3.333, -20}, {-3.333, 10}, {6.667, 10}}, color = {190, 20, 31}));
      connect(switch.y, circulationInDoor.volumeFlow) annotation(Line(visible = true, origin = {8.2, 34}, points = {{-27.2, 26}, {-8.2, 26}, {-8.2, -14}, {31.8, -14}, {31.8, -24}}, color = {1, 37, 163}));
      connect(circulationInDoor.flowPort_b, flowPort_b1) annotation(Line(visible = true, origin = {100, 0}, points = {{-50, 0}, {50, 0}}, color = {190, 20, 31}));
      connect(circulationOutDoor.flowPort_b, ambient.flowPort) annotation(Line(visible = true, origin = {-13.333, -10}, points = {{-6.667, 10}, {3.333, 10}, {3.333, -20}}, color = {190, 20, 31}));
      connect(switch.y, circulationOutDoor.volumeFlow) annotation(Line(visible = true, origin = {-15.8, 34}, points = {{-3.2, 26}, {15.8, 26}, {15.8, -14}, {-14.2, -14}, {-14.2, -24}}, color = {1, 37, 163}));
      connect(flowPort_a1, circulationOutDoor.flowPort_a) annotation(Line(visible = true, origin = {-95, 0}, points = {{-55, 0}, {55, 0}}, color = {190, 20, 31}));
      connect(openCloseTable.y, switch.u2) annotation(Line(visible = true, origin = {-75.5, 60}, points = {{-33.5, 0}, {33.5, 0}}, color = {190, 52, 178}));
      connect(fanOff.y, switch.u3) annotation(Line(visible = true, origin = {-57.75, 74}, points = {{-11.25, 6}, {-2.25, 6}, {-2.25, -6}, {15.75, -6}}, color = {1, 37, 163}));
      connect(fanOn.y, switch.u1) annotation(Line(visible = true, origin = {-57.75, 46}, points = {{-11.25, -6}, {-2.25, -6}, {-2.25, 6}, {15.75, 6}}, color = {1, 37, 163}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART CompartmentDoor -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Compartment Door</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the air flow through the door of a refrigerator or freezer compartment.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.Components.CompartmentDoor#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND CompartmentDoor --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {-20.0, 0.0}, lineColor = {255, 0, 0}, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-60.0, 68.0}, {90.0, 10.0}, {90.0, -10.0}, {-60.0, -68.0}, {-60.0, 68.0}}), Text(visible = true, extent = {{-40.0, -20.0}, {0.0, 20.0}}, textString = "V", fontName = "Arial"), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial"), Line(visible = true, origin = {80.0, 5.0}, points = {{0.0, 75.0}, {0.0, -75.0}}, color = {0, 0, 255}, thickness = 5)}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {5.8035, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 C", fontSize = 12, fontName = "Arial")}));
    end CompartmentDoor;

    model Cooling "Thermostat-controlled cooling"
      Modelica.Thermal.HeatTransfer.Components.Convection convection annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = -540)));
      Modelica.Blocks.Sources.Constant heatTransfer(k = 6) annotation(Placement(visible = true, transformation(origin = {-100.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b freezerAir annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant noHeatTransfer(k = 0) annotation(Placement(visible = true, transformation(origin = {-100.0, 60.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {-40.0, 30.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 360)));
      Modelica.Blocks.Logical.Hysteresis thermostat(uHigh = -14, uLow = -18.5, pre_y_start = false) annotation(Placement(visible = true, transformation(origin = {-40.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {40.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FromKelvin celcius annotation(Placement(visible = true, transformation(origin = {0.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature r134a(T = -26.5) annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(r134a.port, convection.solid) annotation(Line(visible = true, origin = {20, 0}, points = {{-10, 0}, {10, 0}}, color = {191, 0, 0}));
      connect(noHeatTransfer.y, switch.u3) annotation(Line(visible = true, origin = {-75.25, 49}, points = {{-13.75, 11}, {-4.75, 11}, {-4.75, -11}, {23.25, -11}}, color = {1, 37, 163}));
      connect(heatTransfer.y, switch.u1) annotation(Line(visible = true, origin = {-77.75, 16}, points = {{-11.25, -16}, {-2.25, -16}, {-2.25, 6}, {25.75, 6}}, color = {1, 37, 163}));
      connect(freezerAir, temperatureSensor.port) annotation(Line(visible = true, origin = {75, 60}, points = {{75, -60}, {45, -60}, {45, 20}, {-25, 20}}, color = {191, 0, 0}));
      connect(temperatureSensor.T, celcius.Kelvin) annotation(Line(visible = true, origin = {21, 80}, points = {{9, 0}, {-9, 0}}, color = {1, 37, 163}));
      connect(celcius.Celsius, thermostat.u) annotation(Line(visible = true, origin = {-19.5, 80}, points = {{8.5, 0}, {-8.5, 0}}, color = {1, 37, 163}));
      connect(thermostat.y, switch.u2) annotation(Line(visible = true, origin = {-95.75, 40}, points = {{44.75, 40}, {-34.25, 40}, {-34.25, -10}, {43.75, -10}}, color = {190, 52, 178}));
      connect(switch.y, convection.Gc) annotation(Line(visible = true, origin = {17, 23.333}, points = {{-46, 6.667}, {23, 6.667}, {23, -13.333}}, color = {1, 37, 163}));
      connect(convection.fluid, freezerAir) annotation(Line(visible = true, origin = {115, -20}, points = {{-65, 20}, {5, 20}, {5, 20}, {35, 20}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Cooling -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Cooling</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This component models the thermostat-controlled cooling of the freezer compartment.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.Components.Cooling#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Cooling --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {10.0, 60.0}, rotation = -270, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, points = {{-10.0, -10.0}, {0.0, 20.0}, {10.0, -10.0}}), Polygon(visible = true, origin = {-0.0, -60.0}, rotation = -450, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-10.0, -10.0}, {0.0, 20.0}, {10.0, -10.0}}), Line(visible = true, origin = {-40.0, 0.0}, points = {{30.0, 60.0}, {-30.0, 60.0}, {-30.0, -60.0}, {30.0, -60.0}}), Line(visible = true, origin = {45.0, 0.0}, points = {{-25.0, -60.0}, {25.0, -60.0}, {25.0, 60.0}, {-25.0, 60.0}}), Line(visible = true, origin = {85.0, 0.0}, points = {{-15.0, 0.0}, {15.0, 0.0}}), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {-100.0, -20.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.12 m^2 fan forced", fontSize = 12, fontName = "Arial")}));
    end Cooling;
    annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Components -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Simulation of Changing Refrigerator Temperatures</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This subpackage contains components used in the <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, <a href=\"modelica://Refrigerator.HotFood\">HotFood</a>, and <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a> models.
</p><ul><li><a href=\"modelica://Refrigerator.Components.AirCirculation#diagram\">AirCirculation</a>: thermostat-controlled circulation between compartments (<a href=\"modelica://Refrigerator.Components.AirCirculation\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.Components.CompartmentDoor#diagram\">CompartmentDoor</a>: door of refrigerator or freezer compartment (<a href=\"modelica://Refrigerator.Components.CompartmentDoor\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.Components.Cooling#diagram\">Cooling</a>: thermostat-controlled cooling (<a href=\"modelica://Refrigerator.Components.Cooling\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.Components.ConvectionCooledFood#diagram\">ConvectionCooledFood</a>: food cooled by air (<a href=\"modelica://Refrigerator.Components.ConvectionCooledFood\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.Components.OuterCase#diagram\">OuterCase</a>: insulated compartment case (<a href=\"modelica://Refrigerator.Components.OuterCase\">show documentation</a>)</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Components --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {191, 191, 191}, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25)}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
  end Components;

  model DoorOpening "Model simulating effect of opening and closing compartment doors on a refrigerator."
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = 33400, initialTemperature = 257.15, surfaceArea = 1, frozenIcon = true) annotation(Placement(visible = true, transformation(origin = {120, 70}, extent = {{10, 10}, {-10, -10}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = 78800, initialTemperature = 277.15, surfaceArea = 2) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = {690, 720, 1890, 1920, 3090, 3120, 15090, 15120, 16290, 16320, 17490, 17520, 36690, 36720, 37890, 37920, 39090, 39120, 47490, 47520, 48690, 48720, 49890, 49920}, airFlow = 0.05) annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = 0.1, schedule = {600, 620, 1200, 1220, 1800, 1820, 2400, 2420, 3000, 3020, 3600, 3620, 15000, 15020, 15600, 15620, 16200, 16220, 16800, 16820, 17400, 17420, 18000, 18020, 36600, 36620, 37200, 37220, 37800, 37820, 38400, 38420, 39000, 39020, 39600, 39620, 47400, 47420, 48000, 48020, 48600, 48620, 49200, 49220, 49800, 49820, 50400, 50420}) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
  equation
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, 0}, points = {{-9.893, 0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(__Wolfram(PlotSet(plots = {Plot(name = "FrozenFoodAirAndFoodTemperature", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = frozenFood.air.T), Curve(x = time, y = frozenFood.food.T)})}), Plot(name = "FreshFoodAirAndFoodTemperature", subPlots = {SubPlot(curves = {Curve(x = time, y = freshFood.air.T), Curve(x = time, y = freshFood.food.T)})}), Plot(name = "Events", subPlots = {SubPlot(curves = {Curve(x = time, y = airCirculation.switch.u2, legend = "Thermostat control")}, label = Label(x = auto, y = "On/Off")), SubPlot(curves = {Curve(x = time, y = freezerDoor.switch.u2, legend = "Freezer door")}, label = Label(x = auto, y = "Open/Closed")), SubPlot(curves = {Curve(x = time, y = fridgeDoor.switch.u2, legend = "Fridge door")}, label = Label(x = auto, y = "Open/Closed")), SubPlot(curves = {Curve(x = time, y = heatPump.switch.u2, legend = "Heat pump")}, label = Label(x = auto, y = "On/Off"))})})), experiment(StartTime = 0.0, StopTime = 8000, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html><!--WSMINSERTIONTAGSTART DoorOpening -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Refrigerator: Door Opening</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Simulation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Visualization').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Visualization</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_OtherScenarios').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Other Scenarios</a></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This model simulates the effect of opening and closing the refrigerator and freezer compartment doors in a household refrigerator. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.DoorOpening#diagram\">model diagram</a> for this model.
</p><p class=\"\">
The other two models in this example are <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> and <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a>, which compare the effects of adding hot food to a normally loaded and a near-empty refrigerator, respectively.
</p><a id=\"headerTag_Simulation\" class=\"target\">&nbsp;</a>
    <h2>Simulation</h2>
    <p class=\"\">
The model simulates the effect of opening and closing compartment doors according to a prespecified schedule. To see or modify the schedule, select the <span class=\"variablename\">fridgeDoor</span> or <span class=\"variablename\">freezerDoor</span> components in the <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a> model. The schedule is specified in the <span class=\"dialogelement\">Parameters</span> view at the bottom of <i>Model Center</i>.
</p><p class=\"\">
To simulate the model, follow the steps below:
</p><ul><li>Click the <img src=\"modelica://Refrigerator/DocumentationFiles/simCenter.png\" alt=\"simCenter\"/> button in the top-right corner.</li><li>When the build is finished, click the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://Refrigerator/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li></ul><p class=\"\">
By default, the model is simulated over a period of 8000 seconds.
</p><a id=\"headerTag_Visualization\" class=\"target\">&nbsp;</a>
    <h2>Visualization</h2>
    <p class=\"\">
After simulating the model, a preferred stored plot will be displayed, showing the temperature of the air and food in the freezer compartment. An annotated version of the freezer compartment plot looks like this
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/freezerCompartmentDoorOpening.png\" alt=\"freezerCompartmentDoorOpening\"/>
</p><p class=\"\">
You can see that there are several discontinuities in the rate of temperature change corresponding to predetermined events such as compartment doors opening and closing, and dynamic events such as thermostats being triggered.
</p><h3>Visualize Events</h3>
    <p class=\"\">
You can visualize the various discrete events by clicking on the stored plot name <span class=\"dialogelement\">Events</span>
</p><p class=\"\">
The resulting plot looks like this, depending on your choice of styles:
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/discreteEvents.png\" alt=\"discreteEvents\"/>
</p><a id=\"headerTag_OtherScenarios\" class=\"target\">&nbsp;</a>
    <h2>Other Scenarios</h2>
    <p class=\"\">
Try simulating the other two models in this example, <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> and <a href=\"modelica://Refrigerator.HotFood\">NearEmpty</a>, to compare the effects of adding hot food to a normally loaded and near-empty refrigerator, respectively.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND DoorOpening --></html>", revisions = ""), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial")}));
  end DoorOpening;

  model HotFood "Model simulating the effect of adding hot food to refrigerator."
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = 33400, initialTemperature = 257.15, surfaceArea = 1, frozenIcon = true) annotation(Placement(visible = true, transformation(origin = {120.0, 70.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = 78800, initialTemperature = 277.15, surfaceArea = 2) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = {999999, 9999999}, airFlow = 0.05) annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = 0.1, schedule = {999999, 9999999}) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood hotFood(heatCapacity = 7880, initialTemperature = 323.15, surfaceArea = 0.4) annotation(Placement(visible = true, transformation(origin = {90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
  equation
    connect(hotFood.air, fridgeCompartment.heatPort) annotation(Line(visible = true, origin = {40, -85.025}, points = {{50, 44.924}, {50, -4.975}, {-40, -4.975}, {-40, 5.025}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, 0}, points = {{-9.893, 0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(experiment(StartTime = 0.0, StopTime = 7200, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(PlotSet(plots = {Plot(name = "TemperatureHotFoodFreshFoodAndAirInRefrigerator", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = hotFood.temperatureSensor.T), Curve(x = time, y = freshFood.temperatureSensor.T), Curve(x = time, y = airCirculation.celsius.Celsius)})})})), Documentation(info = "<html><!--WSMINSERTIONTAGSTART HotFood -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Refrigerator: Hot Food</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Simulation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Visualization').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Visualization</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_OtherScenario').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Other Scenario</a></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This model simulates the effect of adding hot food to a household refrigerator. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.HotFood#diagram\">model diagram</a> for this model.
</p><p class=\"\">
This model should be compared with the <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a> model, which simulates the addition of hot food to a near-empty refrigerator.
</p><p class=\"\">
The other model in this example is <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, which simulates the effects of opening and closing the compartment doors.
</p><a id=\"headerTag_Simulation\" class=\"target\">&nbsp;</a>
    <h2>Simulation</h2>
    <p class=\"\">
The model simulates the effect of a piece of hot food added at <em>t</em>=0 seconds to a refrigerator already normally loaded with both fresh and frozen food.
</p><p class=\"\">
To simulate the model, follow the steps below:
</p><ul><li>Click the <img src=\"modelica://Refrigerator/DocumentationFiles/simCenter.png\" alt=\"simCenter\"/> button in the top-right corner.</li><li>When the build is finished, click the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://Refrigerator/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li></ul><p class=\"\">
By default, the model is simulated over a period of 7200 seconds.
</p><a id=\"headerTag_Visualization\" class=\"target\">&nbsp;</a>
    <h2>Visualization</h2>
    <p class=\"\">
After simulating the model, look at the displayed plot of the food and air temperatures in the refrigerator compartment. The plot looks like this:
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/hotFoodTemperatures.png\" alt=\"hotFoodTemperatures\"/>
</p><p class=\"\">
You can see that the fresh food temperature increases by about 2 K, which is within acceptable limits.
</p><p class=\"\">
By simulating the <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a> model, you can see the effect of adding hot food to a near-empty refrigerator instead of a normally loaded one:
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/nearEmptyTemperatures.png\" alt=\"nearEmptyTemperatures\"/>
</p><p class=\"\">
You can see that, in the near-empty refrigerator, the fresh food temperature increases by about 7 K, outside acceptable limits. The low thermal mass of the near-empty refrigerator also leads to excessively frequent thermostat switching, visible after <em>t</em>=5500 seconds.
</p><a id=\"headerTag_OtherScenario\" class=\"target\">&nbsp;</a>
    <h2>Other Scenario</h2>
    <p class=\"\">
Try simulating the other model in this example, <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, to explore the effects of opening and closing the refrigerator and freezer compartment doors.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND HotFood --></html>", revisions = ""), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {90.0, -15.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of hot asparagus", fontSize = 12, fontName = "Arial")}));
  end HotFood;

  model NearEmpty "Model simulating the effect of adding hot food to nearly-empty refrigerator."
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = 3340, initialTemperature = 257.15, surfaceArea = 0.1, frozenIcon = true) annotation(Placement(visible = true, transformation(origin = {120.0, 70.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = 7880, initialTemperature = 277.15, surfaceArea = 0.2) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = {999999, 9999999}, airFlow = 0.05) annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = 0.1, schedule = {999999, 9999999}) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood hotFood(heatCapacity = 7880, initialTemperature = 323.15, surfaceArea = 0.4) annotation(Placement(visible = true, transformation(origin = {90.0, -30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
  equation
    connect(hotFood.air, fridgeCompartment.heatPort) annotation(Line(visible = true, origin = {40, -85.025}, points = {{50, 44.924}, {50, -4.975}, {-40, -4.975}, {-40, 5.025}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, 0}, points = {{-9.893, 0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(experiment(StartTime = 0.0, StopTime = 7200, Tolerance = 1e-07, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(PlotSet(plots = {Plot(name = "FoodAirTemperature", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = hotFood.temperatureSensor.T), Curve(x = time, y = freshFood.temperatureSensor.T), Curve(x = time, y = airCirculation.celsius.Celsius)})})})), Documentation(info = "<html><!--WSMINSERTIONTAGSTART NearEmpty -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Near-Empty Refrigerator</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Simulation').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Visualization').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Visualization</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_OtherScenario').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Other Scenario</a></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This model simulates the effect of adding hot food to a household refrigerator that is nearly empty. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.
</p><p class=\"\">
View the <a href=\"modelica://Refrigerator.NearEmpty#diagram\">model diagram</a> for this model.
</p><p class=\"\">
This model should be compared with the <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> model, which simulates the addition of hot food to a normally loaded refrigerator.
</p><p class=\"\">
The other model in this example is <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, which simulates the effects of opening and closing the compartment doors.
</p><a id=\"headerTag_Simulation\" class=\"target\">&nbsp;</a>
    <h2>Simulation</h2>
    <p class=\"\">
The model simulates the effect of a piece of hot food added at <em>t</em>=0 seconds to a refrigerator that is nearly empty, with only a small amount of fresh and frozen food stored in the compartments.
</p><p class=\"\">
To simulate the model, follow the steps below:
</p><ul><li>Click the <img src=\"modelica://Refrigerator/DocumentationFiles/simCenter.png\" alt=\"simCenter\"/> button in the top-right corner.</li><li>When the build is finished, click the <span class=\"dialogelement\">Simulate</span> button <img src=\"modelica://Refrigerator/DocumentationFiles/simulate.png\" alt=\"simulate\"/>.</li></ul><p class=\"\">
By default, the model is simulated over a period of 7200 seconds.
</p><a id=\"headerTag_Visualization\" class=\"target\">&nbsp;</a>
    <h2>Visualization</h2>
    <p class=\"\">
After simulating the model, look at the displayed plot of the food and air temperatures in the refrigerator compartment. The plot looks like this:
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/nearEmptyTemperatures.png\" alt=\"nearEmptyTemperatures\"/>
</p><p class=\"\">
You can see that the fresh food temperature increases by about 7 K, outside acceptable limits. The low thermal mass of the near-empty refrigerator also leads to excessively frequent thermostat switching, visible after <em>t</em>=5500 seconds.
</p><p class=\"\">
By simulating the <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> model, you can see the effect of adding hot food to a normally loaded refrigerator instead of a near-empty one:
</p><p class=\"\">
<img src=\"modelica://Refrigerator/DocumentationFiles/hotFoodTemperatures.png\" alt=\"hotFoodTemperatures\"/>
</p><p class=\"\">
You can see that, in the normally loaded refrigerator, the fresh food temperature increases by about 2 K, which is within acceptable limits.
</p><a id=\"headerTag_OtherScenario\" class=\"target\">&nbsp;</a>
    <h2>Other Scenario</h2>
    <p class=\"\">
Try simulating the other model in this example, <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, to explore the effects of opening and closing the refrigerator and freezer compartment doors.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND NearEmpty --></html>", revisions = ""), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {90.0, -15.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of hot asparagus", fontSize = 12, fontName = "Arial")}));
  end NearEmpty;
  annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART RefrigeratorPackage -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Simulation of Changing Refrigerator Temperatures</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This is a package containing three models of household refrigerator-freezer scenarios, as well as a component library used in the models.
</p><ul><li><a href=\"modelica://Refrigerator.DoorOpening#diagram\">DoorOpening</a>: main model simulating the effect of opening and closing compartment doors (<a href=\"modelica://Refrigerator.DoorOpening\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.HotFood#diagram\">HotFood</a>: model simulating the effect of adding hot food to a refrigerator (<a href=\"modelica://Refrigerator.HotFood\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.NearEmpty#diagram\">NearEmpty</a>: model simulating the effect of hot food on a near-empty refrigerator (<a href=\"modelica://Refrigerator.NearEmpty\">show documentation</a>)</li><li><a href=\"modelica://Refrigerator.Components#info\">Components</a>: library with custom components for the refrigerator</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND RefrigeratorPackage --></html>", revisions = ""), preferredView = "info", uses(Modelica(version = "3.2.3")), __Wolfram(openClass = Refrigerator.DoorOpening, useDocumentationTemplate = false), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
end Refrigerator;